web

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2021 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ByName

type ByName []uiHelmRelease

ByName sorts uiHelmRelease'es by Repository and then image name

func (ByName) Len

func (a ByName) Len() int

func (ByName) Less

func (a ByName) Less(i, j int) bool

func (ByName) Swap

func (a ByName) Swap(i, j int)

type UI

type UI struct {
	// contains filtered or unexported fields
}

UI exposes an html endpoint for Helm Release info

func New

func New(helmReleaseService helmReleaseProvider, webAddress string, log *logrus.Entry) *UI

New returns a new configured instance of the UI struct

func (*UI) Run

func (u *UI) Run(ctx context.Context) error

Run will run the ui server

func (*UI) Shutdown

func (u *UI) Shutdown() error

Shutdown closes the ui server gracefully

Jump to